@@ -28,6 +28,10 @@ class MixedExperimentDatabase(ExperimentDatabase):
 
     def save_experiment(self, experiment: Experiment):
         self.sqldb.save_experiment(experiment)
+        self.influxdb.client.buckets_api().create_bucket(
+            bucket_name=experiment.id,
+            org_id=self.influxdb.org_id
+        )
 
     def update_experiment(self, experiment: Experiment):
         self.sqldb.update_experiment(experiment)
@@ -42,7 +46,7 @@ class MixedExperimentDatabase(ExperimentDatabase):
         self.influxdb.save_traces(traces)
 
     def touch_traces(self, experiment: Experiment):
-        raise NotImplementedError()
+        self.sqldb.touch_traces(experiment)
 
     def get_traces(self, exp_id: str) -> List[RequestTrace]:
         return self.influxdb.get_traces(exp_id)
