@@ -33,7 +33,7 @@ CREATE TABLE IF NOT EXISTS events
     EXP_ID      VARCHAR(100) NOT NULL,
     TIMESTAMP   DOUBLE       NOT NULL,
     NAME        VARCHAR(100) NOT NULL,
-    VALUE       VARCHAR(255)
+    VALUE       TEXT
 );
 
 CREATE TABLE IF NOT EXISTS traces
@@ -46,7 +46,7 @@ CREATE TABLE IF NOT EXISTS traces
     DONE        DOUBLE       NOT NULL,
     STATUS      INT,
     RESPONSE    TEXT,
+    HEADERS      TEXT,
     SERVER      VARCHAR (50),
-    EXP_ID      VARCHAR (100),
-    CONSTRAINT traces_pk PRIMARY KEY (REQUEST_ID)
+    EXP_ID      VARCHAR (100)
 );
